# -*- coding: utf-8 -*-
# Copyright (C) 2015-2020 SHS-AV s.r.l. (<http://www.zeroincombenze.org>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from . import z0testlib

Z0test = z0testlib.Z0test()
Z0BUG = z0testlib.Z0test()
Z0testOdoo = z0testlib.Z0testOdoo()
